# 🔥 flamethrower

The ultimate debugging experience.

## Usage

1. Pip install

    ```
    pip install flamethrower
    ```
    `WARN`: this installs `flamethrower` deps into your global python environment -- which you will need if you want to run flamethrower on any workspace.

2. Export OpenAI key for `flamethrower` to use

    ```
    EXPORT OPENAI_API_KEY=sk-xxxx
    ```

3. In whatever workspace/repo you're on, just type `flamethrower` or `ft`

    ```
    pwd
    flamethrower
    ```

    flamethrower will gain an understanding of your project and directory structure.

4. Use it as a regular shell: you can both run commands and ask natural language queries

    ```
    python main.py # or node server.ts or whatever your run script is
    Wtf? Why did that happen? # natural language queries start with a capital letter
    ```
